@@ -15,9 +15,11 @@ TEMPLATE_MAP = {
    ProjectType.LIGHTNINGJS: "lightningjs-kavia",
    ProjectType.NATIVESCRIPT: "nativescript-kavia",
    ProjectType.NEXTJS: "nextjs-kavia",
+   ProjectType.SOLANANEXTJS: "solananextjs-kavia",
    ProjectType.NUXT: "nuxt-kavia",
    ProjectType.QWIK: "qwik-kavia",
    ProjectType.REACT : "react-kavia",
+   ProjectType.REACT_NATIVE : "reactnative-kavia",
    ProjectType.REMIX : "remix-kavia",
    ProjectType.REMOTION: "remotion-kavia",
    ProjectType.SLIDEV: "slidev-kavia",
@@ -29,4 +31,5 @@ TEMPLATE_MAP = {
    ProjectType.MONGODB: "mongodb-kavia",
    ProjectType.MYSQL: "mysql-kavia",
    ProjectType.SQLITE: "sqlite-kavia",
+   ProjectType.NATIVE: "native",
 }
