@@ -1,10 +1,13 @@
 package com.example.{KAVIA_TEMPLATE_PROJECT_NAME};
 
+import io.swagger.v3.oas.annotations.Operation;
+import io.swagger.v3.oas.annotations.tags.Tag;
+import jakarta.servlet.http.HttpServletRequest;
+import org.springframework.http.server.ServletServerHttpRequest;
 import org.springframework.web.bind.annotation.GetMapping;
 import org.springframework.web.bind.annotation.RestController;
 import org.springframework.web.servlet.view.RedirectView;
-import io.swagger.v3.oas.annotations.Operation;
-import io.swagger.v3.oas.annotations.tags.Tag;
+import org.springframework.web.util.UriComponentsBuilder;
 
 @RestController
 @Tag(name = "Hello Controller", description = "Basic endpoints for {KAVIA_TEMPLATE_PROJECT_NAME}")
@@ -17,9 +20,20 @@ public class HelloController {
     }
     
     @GetMapping("/docs")
-    @Operation(summary = "API Documentation", description = "Redirects to Swagger UI")
-    public RedirectView docs() {
-        return new RedirectView("/swagger-ui.html");
+    @Operation(summary = "API Documentation", description = "Redirects to Swagger UI preserving original scheme/host/port")
+    public RedirectView docs(HttpServletRequest request) {
+        // Build an absolute URL based on the incoming request, honoring X-Forwarded-* headers
+        String target = UriComponentsBuilder
+                .fromHttpRequest(new ServletServerHttpRequest(request))
+                .replacePath("/swagger-ui.html")
+                .replaceQuery(null)
+                .build()
+                .toUriString();
+
+        RedirectView rv = new RedirectView(target);
+        // Use HTTP 1.1 compatible redirects when necessary (preserves 303/307 semantics if used)
+        rv.setHttp10Compatible(false);
+        return rv;
     }
     
     @GetMapping("/health")
