@@ -269,9 +269,11 @@ class ProjectInitializer:
         self.template_factory.register_template(ProjectType.LIGHTNINGJS, LightningjsTemplate)
         self.template_factory.register_template(ProjectType.NATIVESCRIPT, NativeScriptTemplate)
         self.template_factory.register_template(ProjectType.NEXTJS, NextJSTemplate)
+        self.template_factory.register_template(ProjectType.SOLANANEXTJS, SolanaNextJSTemplate)
         self.template_factory.register_template(ProjectType.NUXT, NuxtTemplate)
         self.template_factory.register_template(ProjectType.QWIK, QwikTemplate)
         self.template_factory.register_template(ProjectType.REACT, ReactTemplate)
+        self.template_factory.register_template(ProjectType.REACT_NATIVE, ReactNativeTemplate)
         self.template_factory.register_template(ProjectType.REMIX, RemixTemplate)
         self.template_factory.register_template(ProjectType.REMOTION, RemotionTemplate)
         self.template_factory.register_template(ProjectType.SLIDEV, SlidevTemplate)
@@ -291,6 +293,7 @@ class ProjectInitializer:
         self.template_factory.register_template(ProjectType.MONGODB, MongoDBTemplate)
         self.template_factory.register_template(ProjectType.MYSQL, MySQLTemplate)
         self.template_factory.register_template(ProjectType.SQLITE, SQLiteTemplate)
+        self.template_factory.register_template(ProjectType.NATIVE, CommonTemplate)
         self.template = None
     def initialize_project(self, config: ProjectConfig) -> bool:
         """Initialize a project using the appropriate template."""
@@ -347,6 +350,25 @@ class AndroidTemplate(ProjectTemplate):
         # Testing is already configured in the template
         pass
 
+class CommonTemplate(ProjectTemplate):
+    """Template implementation for Angular projects."""
+
+    def validate_parameters(self) -> bool:
+        return True
+
+    def generate_structure(self) -> None:
+        replacements = self.config.get_replaceable_parameters()
+        
+        FileSystemHelper.copy_template(
+            self.template_path,
+            self.config.output_path,
+            replacements,
+            include_hidden=True
+        )
+
+    def setup_testing(self) -> None:
+        pass
+
 
 class AngularTemplate(ProjectTemplate):
     """Template implementation for Angular projects."""
@@ -592,7 +614,7 @@ class KotlinTemplate(ProjectTemplate):
 
 
 class LightningjsTemplate(ProjectTemplate):
-    """Template implementation for NextJS projects."""
+    """Template implementation for LightningJS projects."""
 
     def validate_parameters(self) -> bool:
         # Lightningjs has no required parameters for basic setup
@@ -661,6 +683,31 @@ class NextJSTemplate(ProjectTemplate):
         pass
 
 
+class SolanaNextJSTemplate(ProjectTemplate):
+    """Template implementation for Solana-NextJS projects."""
+
+    def validate_parameters(self) -> bool:
+        required_params = {'typescript', 'styling_solution'}
+        for param in required_params:
+            if param not in self.config.parameters:
+                self.config.parameters[param] = True if param == 'typescript' else 'css'
+        return True
+
+    def generate_structure(self) -> None:
+        replacements = self.config.get_replaceable_parameters()
+        
+        FileSystemHelper.copy_template(
+            self.template_path,
+            self.config.output_path,
+            replacements,
+            include_hidden=True  # Include .gitignore, .eslintrc, etc.
+        )
+
+    def setup_testing(self) -> None:
+        # Testing is already configured in the NextJS template
+        pass
+
+
 class NuxtTemplate(ProjectTemplate):
     """Template implementation for Nuxt projects."""
 
@@ -732,6 +779,26 @@ class ReactTemplate(ProjectTemplate):
             )
 
 
+class ReactNativeTemplate(ProjectTemplate):
+    """Template implementation for React projects."""
+
+    def validate_parameters(self) -> bool:
+        return True
+
+    def generate_structure(self) -> None:
+        replacements = self.config.get_replaceable_parameters()
+
+        FileSystemHelper.copy_template(
+            self.template_path,
+            self.config.output_path,
+            replacements,
+            include_hidden=True
+        )
+
+    def setup_testing(self) -> None:
+        pass
+
+
 class RemixTemplate(ProjectTemplate):
     """Template implementation for Remix projects."""
 
@@ -907,7 +974,11 @@ class PostgreSQLTemplate(ProjectTemplate):
             self.config.output_path,
             replacements,
             include_hidden=True,
-            extra_files=[ str(Path.joinpath(base_path, 'db_visualizer')) ],
+            extra_files=[
+                str(Path.joinpath(base_path, 'db_visualizer')),
+                str(Path.joinpath(base_path, 'backup_db.sh')),
+                str(Path.joinpath(base_path, 'restore_db.sh')),
+            ],
         )
 
     def setup_testing(self) -> None:
@@ -929,7 +1000,11 @@ class MongoDBTemplate(ProjectTemplate):
             self.config.output_path,
             replacements,
             include_hidden=True,
-            extra_files=[ str(Path.joinpath(base_path, 'db_visualizer')) ],
+            extra_files=[
+                str(Path.joinpath(base_path, 'db_visualizer')),
+                str(Path.joinpath(base_path, 'backup_db.sh')),
+                str(Path.joinpath(base_path, 'restore_db.sh')),
+            ],
         )
 
     def setup_testing(self) -> None:
@@ -951,7 +1026,11 @@ class MySQLTemplate(ProjectTemplate):
             self.config.output_path,
             replacements,
             include_hidden=True,
-            extra_files=[ str(Path.joinpath(base_path, 'db_visualizer')) ],
+            extra_files=[
+                str(Path.joinpath(base_path, 'db_visualizer')),
+                str(Path.joinpath(base_path, 'backup_db.sh')),
+                str(Path.joinpath(base_path, 'restore_db.sh')),
+            ],
         )
 
     def setup_testing(self) -> None:
@@ -973,7 +1052,11 @@ class SQLiteTemplate(ProjectTemplate):
             self.config.output_path,
             replacements,
             include_hidden=True,
-            extra_files=[ str(Path.joinpath(base_path, 'db_visualizer')) ],
+            extra_files=[
+                str(Path.joinpath(base_path, 'db_visualizer')),
+                str(Path.joinpath(base_path, 'backup_db.sh')),
+                str(Path.joinpath(base_path, 'restore_db.sh')),
+            ],
         )
 
     def setup_testing(self) -> None:
